@@ -26,14 +26,14 @@
 #' Stdi <- stdvals[2]
 #' @export
 std <- function(x, create_plot = FALSE, option = c(1, 2)) {
-  if(class(x)[1] != 'RasterLayer' & class(x)[1] != 'matrix') {stop('x must be a raster or matrix.')}
-  if(class(create_plot) != 'logical') {stop('create_plot must be logical.')}
+  if(inherits(x, "RasterLayer") == FALSE & inherits(x, "matrix") == FALSE) {stop('x must be a raster or matrix.')}
+  if(inherits(create_plot, "logical") == FALSE) {stop('create_plot must be logical.')}
 
   # get raster dimensions
   M <- ncol(x)
   N <- nrow(x)
 
-  data_type <- if(class(x)[1] == 'matrix') {'matrix'} else {'RasterLayer'}
+  data_type <- if(inherits(x, "matrix") == TRUE) {'matrix'} else {'RasterLayer'}
 
   # convert matrix to raster if necessary (equal area)
   if (data_type == 'matrix') {
@@ -223,14 +223,14 @@ std <- function(x, create_plot = FALSE, option = c(1, 2)) {
 #' Shw <- srwvals[3]
 #' @export
 srw <- function(x, create_plot = FALSE, option = c(1, 2, 3)) {
-  if(class(x)[1] != 'RasterLayer' & class(x)[1] != 'matrix') {stop('x must be a raster or matrix.')}
-  if(class(create_plot) != 'logical') {stop('create_plot must be logical.')}
+  if(inherits(x, "RasterLayer") == FALSE & inherits(x, "matrix") == FALSE) {stop('x must be a raster or matrix.')}
+  if(inherits(create_plot, "logical") == FALSE) {stop('create_plot must be logical.')}
 
   # get raster dimensions
   M <- ncol(x)
   N <- nrow(x)
 
-  data_type <- if(class(x)[1] == 'matrix') {'matrix'} else {'RasterLayer'}
+  data_type <- if(inherits(x, "matrix") == TRUE) {'matrix'} else {'RasterLayer'}
 
   # convert matrix to raster if necessary (equal area)
   if (data_type == 'matrix') {
